# DVQ - DNA Validator and Quick comparator 
This package provides some usefull functions to compare lists of DNA sequences both visually and statistically 

## Commands:

* Use dvq
```python
from dvq import visual

visual.2d_representation([sequences_1, sequences_2], labels=['])
```
